# ChangeLog

## 1.1.6
* Delete debug code

## 1.1.5
* Bugfix
* Modify readme
* Adjust ChangeLog

## 1.1.4.post1
* Modify readme

## 1.1.4
* Bugfix

## 1.1.3
* Bugfix (monaural only)

## 1.1.2
* Bugfix
* Process speed up↑↑

## 1.1.1
* Bugfix

## 1.1.0
* add function: trim
* add cli command: pysaten_trim

## 1.0.0.post4
* Add original of test code (MarbleNet)

## 1.0.0.post3
* Modify readme

## 1.0.0.post2
* Modify readme

## 1.0.0.post1
* Organising the commit log

## 1.0.0
* First Release
